==> dl-0.0.1.tgz: package/lib/cdf/CdfPage.js <==
var Class           = require("core").Class;
var Event           = require("core").Event.Event;
var ErrorEvent      = require("core").Event.ErrorEvent;
var EventDispatcher = require("core").Event.EventDispatcher;

var CdfBlock   = require('./CdfBlock.js').CdfBlock;
var CdfInsert  = require('./CdfInsert.js').CdfInsert;
var CdfConfig  = require('./CdfConfig.js').CdfConfig;
var CdfBlocks  = require('./CdfBlocks.js').CdfBlocks;
var CdfInserts = require('./CdfInserts.js').CdfInserts;

var CDF_TAG_PATTERN = /(<cdf:(.|\s)+?(<\/cdf:[^>]+>))/ig
var CDF_INSERT_PATTERN = /(<cdf:insert(.|\s)+?(<\/cdf:[^>]+>))/ig;
var CDF_BLOCK_PATTERN = /(<cdf:block(.|\s)+?(<\/cdf:[^>]+>))/ig;
var CDF_CONFIG_PATTERN = /(<cdf:config(.|\s)+?(<\/cdf:[^>]+>))/ig;


var CdfPage = function(){
    this.Extends = EventDispatcher;
    
    this._data = "";
    
    this.inserts = null;
    this.blocks = null;
    this.config = null;
    this.layout = null;
    
    
    /**
     * Parsuje zadanego stringa w poszukiwaniu cdf:mode i cdf:target 
     * @ignore
     */
    this.initialize = function(data){
       
        this.inserts = new CdfInserts();
        this.blocks = new CdfBlocks();
        
        this._data = data;


        // parse cdf config
        var chunks = data.match(CDF_CONFIG_PATTERN);
        if(chunks){
            this.config = new CdfConfig(chunks[0]);
            if(this.config.main){
                this._data = "";
            }
        }
        
        //parse data
        chunks = data.match(CDF_BLOCK_PATTERN);
        if(chunks){
            var model, chunk = null;
            for(var i = 0, max = chunks.length; i < max; i++){
                chunk = chunks[i];
                model = new CdfBlock(chunk);
                this.blocks.add( model );
                if(this.config && this.config.main){
                    if(model.name==this.config.main){
                        this.layout = model;
                    }
                    this._data += model.token;
                }                
            }
        }
    };
    
    this.render = function(){
        
        console.log('     -- CDF Page Render:');
        
        var body = this._data;

        if(this.layout){
            console.log('        -- I HAVE special layout model');
            if(!this.layout.isCacheable()){
                this.dispatchEvent( new Event(CdfPage.Event.CACHE_REDY, body));
            } else{
                body = body.replace(this.layout.token, this.layout.getRenderedData()+"\n\n");
            }
        } else {
            console.log('        -- I DONT HAVE special layout model');
        }
        


        console.log('        -- Finding targets...');
        var target = null, chunk = "", chunks = body.match( CDF_INSERT_PATTERN );
        if(chunks){
            for(var i=0,max=chunks.length;i<max;i++){
                chunk = chunks[i];
                target = new CdfInsert(chunk);
                if(this.blocks.hasTarget(target.id)){
                    
                    this.inserts.add(new CdfInsert(chunk));    
                }
                else{
                    body.replace(chunk, "");
                }
            }            
        }
        console.log('        -- Targets found: ' + this.inserts.getLength());
        
        if(this.blocks.hasCacheableModels()){
            console.log('        -- Replacing CACHEABLE models...');
            body = this._replaceCdf(body, this.blocks.getCacheableModels() );
            this.dispatchEvent(new Event(CdfPage.Event.CACHE_READY, body));
        } else {
            console.log('        -- There is no CACHABLE models');
        }
        
        console.log('        -- Replacing NONCACHEABLE models...');
        body = this._replaceCdf(body, this.blocks.getNonCacheableModels());
        this.dispatchEvent(new Event(CdfPage.Event.RENDERED, body));
        
    };
    
    this._replaceCdf = function(body, models){
        console.log('           -- replacing '+models.length+" blocks");
        if(models){
            var model = null, insert = null;
        
            for(var i=0, max=models.length; i<max;i++){
                model = models[i];
                if(model.name){
                    insert = this.inserts.getById(model.name);
                    if(insert){
                        console.log('           -- Replacing insert with block -> '+model.name);
                        body = body.replace(model.token, '');
                        body = body.replace(insert.token, model.getRenderedData());
                    } else {
                        console.log('           -- NOTICE: Cannot find \'insert\' for block: '+model.name);
                        console.log('           -- Replacing block "in place" -> '+model.name);
                        body = body.replace(model.token, model.getRenderedData());
                    }
                } else {
                    console.log('           -- WARNING: BLOCK without name!');
                    body = body.replace(model.token, model.getRenderedData());
                }
            }
        }
        console.log('           -- replace CDF finished!');
        return body;
    };
}

CdfPage = new Class( new CdfPage() );

CdfPage.Event = {};
CdfPage.Event.RENDERED = "PAGE_RENDERED";
CdfPage.Event.CACHE_REDY = "PAGE_CACHE_REDY";
CdfPage.Event.ERROR = "PAGE_ERROR";
exports.CdfPage = CdfPage;

==> dl-0.0.3.tgz: package/lib/cdf/CdfPage.js <==
var Class           = require("core").Class;
var Event           = require("core").Event.Event;
var ErrorEvent      = require("core").Event.ErrorEvent;
var EventDispatcher = require("core").Event.EventDispatcher;

var CdfBlock   = require('./CdfBlock.js').CdfBlock;
var CdfInsert  = require('./CdfInsert.js').CdfInsert;
var CdfConfig  = require('./CdfConfig.js').CdfConfig;
var CdfBlocks  = require('./CdfBlocks.js').CdfBlocks;
var CdfInserts = require('./CdfInserts.js').CdfInserts;

var CDF_TAG_PATTERN = /(<cdf:(.|\s)+?(<\/cdf:[^>]+>))/ig
var CDF_INSERT_PATTERN = /(<cdf:insert(.|\s)+?(<\/cdf:[^>]+>))/ig;
var CDF_BLOCK_PATTERN = /(<cdf:block(.|\s)+?(<\/cdf:[^>]+>))/ig;
var CDF_CONFIG_PATTERN = /(<cdf:config(.|\s)+?(<\/cdf:[^>]+>))/ig;


var CdfPage = function(){
    this.Extends = EventDispatcher;
    
    this._data = "";
    
    this.inserts = null;
    this.blocks = null;
    this.config = null;
    this.layout = null;
    
    
    /**
     * Parsuje zadanego stringa w poszukiwaniu cdf:mode i cdf:target 
     * @ignore
     */
    this.initialize = function(data){
       
        this.inserts = new CdfInserts();
        this.blocks = new CdfBlocks();
        
        this._data = data;


        // parse cdf config
        var chunks = data.match(CDF_CONFIG_PATTERN);
        if(chunks){
            this.config = new CdfConfig(chunks[0]);
            if(this.config.main){
                this._data = "";
            }
        }
        
        //parse data
        chunks = data.match(CDF_BLOCK_PATTERN);
        if(chunks){
            var model, chunk = null;
            for(var i = 0, max = chunks.length; i < max; i++){
                chunk = chunks[i];
                model = new CdfBlock(chunk);
                this.blocks.add( model );
                if(this.config && this.config.main){
                    if(model.name==this.config.main){
                        this.layout = model;
                    }
                    this._data += model.token;
                }                
            }
        }
    };
    
    this.render = function(){
        
        console.log('     -- CDF Page Render:');
        
        var body = this._data;

        if(this.layout){
            console.log('        -- I HAVE special layout model');
            if(!this.layout.isCacheable()){
                // fixme czy czasem to ze dam tutaj content cdfowy to i tak nie jest zle?
                var cachedBody = body + this.config.token;
                this.dispatchEvent( new Event(CdfPage.Event.CACHE_READY, cachedBody));
                body = body.replace(this.layout.token, this.layout.getRenderedData()+"\n\n");
            } else{
                body = body.replace(this.layout.token, this.layout.getRenderedData()+"\n\n");
            }
        } else {
            console.log('        -- I DONT HAVE special layout model');
        }


        console.log('        -- Finding targets...');
        var target = null, chunk = "", chunks = body.match( CDF_INSERT_PATTERN );
        if(chunks){
            for(var i=0,max=chunks.length;i<max;i++){
                chunk = chunks[i];
                target = new CdfInsert(chunk);
                if(this.blocks.hasTarget(target.id)){
                    
                    this.inserts.add(new CdfInsert(chunk));    
                }
                else{
                    body.replace(chunk, "");
                }
            }            
        }
        console.log('        -- Targets found: ' + this.inserts.getLength());
        
        if(this.blocks.hasCacheableModels()){
            console.log('        -- Replacing CACHEABLE models...');
            body = this._replaceCdf(body, this.blocks.getCacheableModels() );
            this.dispatchEvent(new Event(CdfPage.Event.CACHE_READY, body));
        } else {
            console.log('        -- There is no CACHABLE models');
        }
        
        console.log('        -- Replacing NONCACHEABLE models...');
        body = this._replaceCdf(body, this.blocks.getNonCacheableModels());
        this.dispatchEvent(new Event(CdfPage.Event.RENDERED, body));
        
    };
    
    this._replaceCdf = function(body, models){
        console.log('           -- replacing '+models.length+" blocks");
        if(models){
            var model = null, insert = null;
        
            for(var i=0, max=models.length; i<max;i++){
                model = models[i];
                if(model.name){
                    insert = this.inserts.getById(model.name);
                    if(insert){
                        console.log('           -- Replacing insert with block -> '+model.name);
                        body = body.replace(model.token, '');
                        body = body.replace(insert.token, model.getRenderedData());
                    } else {
                        console.log('           -- NOTICE: Cannot find \'insert\' for block: '+model.name);
                        console.log('           -- Replacing block "in place" -> '+model.name);
                        body = body.replace(model.token, model.getRenderedData());
                    }
                } else {
                    console.log('           -- WARNING: BLOCK without name!');
                    body = body.replace(model.token, model.getRenderedData());
                }
            }
        }
        console.log('           -- replace CDF finished!');
        return body;
    };
}

CdfPage = new Class( new CdfPage() );

CdfPage.Event = {};
CdfPage.Event.RENDERED = "PAGE_RENDERED";
CdfPage.Event.CACHE_REDY = "PAGE_CACHE_REDY";
CdfPage.Event.ERROR = "PAGE_ERROR";
exports.CdfPage = CdfPage;
